@@ -17,8 +17,8 @@ pub use chrom::Chrom;
 
 #[cfg(all(feature = "mapped_io", not(target_arch = "wasm32")))]
 pub use d4file::{
-    find_tracks, find_tracks_in_file, D4FileBuilder, D4FileMerger, D4FileWriter, D4MatrixReader,
-    D4TrackReader, MultiTrackReader, D4FileWriterExt
+    find_tracks, find_tracks_in_file, D4FileBuilder, D4FileMerger, D4FileWriter, D4FileWriterExt,
+    D4MatrixReader, D4TrackReader, MultiTrackReader,
 };
 
 pub use dict::Dictionary;
